@@ -1,3 +1,3 @@
 from autolens.pipeline.phase.dataset.analysis import Analysis
-from autolens.pipeline.phase.dataset.meta_dataset import MetaLens
+from autolens.pipeline.phase.dataset.phase import PhaseDataset
 from autolens.pipeline.phase.dataset.result import Result
