@@ -1,6 +1,7 @@
+from autofit.exc import PriorException
 import autoarray as aa
 import autogalaxy as ag
-from autolens.fit import fit_positions
+from autolens.fit import fit_point_source
 from autogalaxy.pipeline.phase import dataset
 from autolens.pipeline.phase.extensions.stochastic_phase import StochasticPhase
 from autolens import exc
@@ -35,7 +36,28 @@ class PhaseDataset(dataset.PhaseDataset):
         self.settings.settings_lens = self.settings.settings_lens.modify_positions_threshold(
             positions_threshold=positions_threshold
         )
-        #   self.check_positions(positions=dataset.positions)
+
+        if self.settings.settings_lens.auto_einstein_radius_factor is not None:
+
+            if results is not None:
+
+                if results.last is not None:
+
+                    if results.last.max_log_likelihood_tracer.has_mass_profile:
+
+                        einstein_radius = results.last.max_log_likelihood_tracer.einstein_radius_from_grid(
+                            grid=dataset.data.mask.unmasked_grid_sub_1
+                        )
+
+                        self.settings.settings_lens = self.settings.settings_lens.modify_einstein_radius_estimate(
+                            einstein_radius_estimate=einstein_radius
+                        )
+
+        else:
+
+            self.settings.settings_lens = self.settings.settings_lens.modify_einstein_radius_estimate(
+                einstein_radius_estimate=None
+            )
 
         preload_sparse_grids_of_planes = self.preload_pixelization_grids_of_planes_from_results(
             results=results
@@ -79,15 +101,13 @@ class PhaseDataset(dataset.PhaseDataset):
 
             # TODO : Coorrdinates refascotr will sort out index call here
 
-            if isinstance(updated_positions, aa.GridIrregularGrouped):
-                if updated_positions.in_grouped_list:
-                    if len(updated_positions.in_grouped_list[0]) > 1:
-                        return updated_positions
+            if isinstance(updated_positions, aa.Grid2DIrregular):
+                if len(updated_positions.in_list) > 1:
+                    return updated_positions
 
         if results.last is not None:
             if results.last.positions is not None:
-                if results.last.positions.in_grouped_list:
-                    return results.last.positions
+                return results.last.positions
 
         return positions
 
@@ -126,15 +146,15 @@ class PhaseDataset(dataset.PhaseDataset):
             if positions is None:
                 return None
 
-            positions_fits = fit_positions.FitPositionsSourcePlaneMaxSeparation(
-                positions=aa.GridIrregularGrouped(grid=positions),
+            positions_fits = fit_point_source.FitPositionsSourceMaxSeparation(
+                positions=positions,
+                noise_map=None,
                 tracer=results.last.max_log_likelihood_tracer,
-                noise_value=1.0,
             )
 
             positions_threshold = (
                 self.settings.settings_lens.auto_positions_factor
-                * np.max(positions_fits.maximum_separations)
+                * np.max(positions_fits.max_separation_of_source_plane_positions)
             )
 
         else:
@@ -174,17 +194,6 @@ class PhaseDataset(dataset.PhaseDataset):
                     return results.last.max_log_likelihood_pixelization_grids_of_planes
         return None
 
-    def check_positions(self, positions):
-
-        if (
-            self.settings.settings_lens.positions_threshold is not None
-            and positions is None
-        ):
-            raise exc.PhaseException(
-                "You have specified for a phase to use positions, but not input positions to the "
-                "pipeline when you ran it."
-            )
-
     def extend_with_stochastic_phase(
         self,
         stochastic_search=None,
@@ -195,6 +204,12 @@ class PhaseDataset(dataset.PhaseDataset):
         stochastic_sigma=0.0,
     ):
 
+        if not hasattr(self.model.galaxies, "lens"):
+            raise PriorException(
+                "Cannot extend a phase with a stochastic phase if the lens galaxy `GalaxyModel` "
+                "is not named `lens`. "
+            )
+
         if stochastic_search is None:
             stochastic_search = self.search.copy_with_name_extension(extension="")
 
